@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
-#     parts from me are licensed as below. It is at least Free Softwar where
+#     parts from me are licensed as below. It is at least Free Software where
 #     it's copied from other people. In these cases, that will normally be
 #     indicated.
 #
@@ -189,16 +189,60 @@ for filename in sorted(os.listdir('.')):
             continue
 
     if filename == "TkInterUsing.py":
-        if not hasModule("tkinter"):
+        if python_version.startswith("2"):
+            if not hasModule("Tkinter"):
+                my_print(
+                    "Skipping", filename, "Tkinter not installed for",
+                    python_version, "but test needs it."
+                )
+                continue
+        else:
+            if not hasModule("tkinter"):
+                my_print(
+                    "Skipping", filename, "tkinter not installed for",
+                    python_version, "but test needs it."
+                )
+                continue
+
+            # For the warnings.
+            extra_flags.append("ignore_stderr")
+
+
+    if filename == "FlaskUsing.py":
+        if not hasModule("flask"):
             my_print(
-                "Skipping", filename, "tkinter not installed for",
+                "Skipping", filename, "flask not installed for",
                 python_version, "but test needs it."
             )
             continue
 
+        # For the warnings.
+        extra_flags.append("ignore_stderr")
+
+    if filename == "NumpyUsing.py":
+        if not hasModule("numpy"):
+            my_print(
+                "Skipping", filename, "numpy not installed for",
+                python_version, "but test needs it."
+            )
+            continue
+
+        extra_flags.append("plugin_enable:data-files")
+
+    if filename == "PmwUsing.py":
+        if not hasModule("Pwm"):
+            my_print(
+                "Skipping", filename, "Pwm not installed for",
+                python_version, "but test needs it."
+            )
+            continue
+
+        extra_flags.append("plugin_enable:pmw-freeze")
+
     if filename not in ("PySideUsing.py", "PyQt4Using.py", "PyQt5Using.py",
                         "PyQt4Plugins.py", "PyQt5Plugins.py", "GtkUsing.py",
-                        "LxmlUsing.py", "Win32ComUsing.py", "IdnaUsing.py"):
+                        "LxmlUsing.py", "Win32ComUsing.py", "IdnaUsing.py",
+                        "NumpyUsing.py", "FlaskUsing.py"):
         extra_flags += [
             "no_site"
         ]
@@ -355,6 +399,10 @@ for filename in sorted(os.listdir('.')):
         if loaded_filename in ("/sys/fs/selinux", "/selinux"):
             continue
 
+        # Allow reading time zone info of local system.
+        if loaded_filename.startswith("/usr/share/zoneinfo/"):
+            continue
+
         # The access to .pth files has no effect.
         if loaded_filename.endswith(".pth"):
             continue
