@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -168,10 +168,12 @@ def convertUsing2to3(path, force = False):
         path
     ]
 
-    if not force and "xrange" not in open(path).read():
-        with open(os.devnull, 'w') as stderr:
-            if check_result(command, stderr = stderr):
-                return path, False
+    if not force:
+        with open(path) as source_file:
+            if "xrange" not in source_file.read():
+                with open(os.devnull, 'w') as stderr:
+                    if check_result(command, stderr = stderr):
+                        return path, False
 
     filename = os.path.basename(path)
 
@@ -371,17 +373,23 @@ def getRuntimeTraceOfLoadedFiles(path, trace_error = True):
     result = []
 
     if os.name == "posix":
-        if sys.platform == "darwin":
+        if sys.platform == "darwin" or \
+           sys.platform.startswith("freebsd"):
             if not isExecutableCommand("dtruss"):
                 sys.exit(
                     """\
 Error, needs 'dtruss' on your system to scan used libraries."""
                 )
 
+            if not isExecutableCommand("sudo"):
+                sys.exit(
+                    """\
+Error, needs 'sudo' on your system to scan used libraries."""
+                )
+
             args = (
                 "sudo",
                 "dtruss",
-                "-f",
                 "-t",
                 "open",
                 path
@@ -557,7 +565,7 @@ def checkReferenceCount(checked_function, max_rounds = 10):
     assert max_rounds > 0
     for count in range(max_rounds):
         gc.collect()
-        ref_count1 = sys.gettotalrefcount()
+        ref_count1 = sys.gettotalrefcount()  # @UndefinedVariable
 
         if explain and count == max_rounds - 1:
             snapObjRefCntMap(True)
@@ -572,7 +580,7 @@ def checkReferenceCount(checked_function, max_rounds = 10):
         if explain and count == max_rounds - 1:
             snapObjRefCntMap(False)
 
-        ref_count2 = sys.gettotalrefcount()
+        ref_count2 = sys.gettotalrefcount()  # @UndefinedVariable
 
         if ref_count1 == ref_count2:
             result = True
@@ -648,8 +656,10 @@ def createSearchMode():
                 dirname,
                 filename,
                 filename.replace(".py", ""),
+                filename.split(".")[0],
                 path,
-                path.replace(".py", "")
+                path.replace(".py", ""),
+
             )
 
         def isCoverage(self):
@@ -794,6 +804,7 @@ def indentedCode(codes, count):
     """
     return '\n'.join( ' ' * count + line if line else "" for line in codes )
 
+
 def convertToPython(doctests, line_filter = None):
     """ Convert give doctest string to static Python code.
 
@@ -821,17 +832,29 @@ def convertToPython(doctests, line_filter = None):
             while evaluated.startswith(' ' * count):
                 count += 1
 
-            modified = (count-1) * ' ' + "print(" + evaluated + "\n)\n"
-            return (count-1) * ' ' + ("print('Line %d'" % line_number) + ")\n" + modified
+            if sys.version_info < (3,):
+                modified = (count-1) * ' ' + "print " + evaluated
+                return (count-1) * ' ' + ("print 'Line %d'" % line_number) + "\n" + modified
+            else:
+                modified = (count-1) * ' ' + "print(" + evaluated + "\n)\n"
+                return (count-1) * ' ' + ("print('Line %d'" % line_number) + ")\n" + modified
         else:
             return evaluated
 
     def getTried(evaluated):
-        return """
+        if sys.version_info < (3,):
+            return """
 try:
 %(evaluated)s
-except Exception as e:
-    print("Occurred", type(e), e)
+except Exception as __e:
+    print "Occurred", type(__e), __e
+""" % { "evaluated" : indentedCode(getPrintPrefixed(evaluated).split('\n'), 4) }
+        else:
+            return """
+try:
+%(evaluated)s
+except Exception as __e:
+    print("Occurred", type(__e), __e)
 """ % { "evaluated" : indentedCode(getPrintPrefixed(evaluated).split('\n'), 4) }
 
     def isOpener(evaluated):
@@ -852,7 +875,7 @@ except Exception as e:
             continue
 
         if inside and len(line) > 0 and line[0].isalnum() and not isOpener(line):
-            output.append(getTried('\n'.join(chunk)))
+            output.append(getTried('\n'.join(chunk)))  # @UndefinedVariable
 
             chunk = []
             inside = False
@@ -879,3 +902,56 @@ except Exception as e:
             output.append(getTried(line))
 
     return '\n'.join(output).rstrip() + '\n'
+
+
+def compileLibraryPath(search_mode, path, stage_dir, decide, action):
+    my_print("Checking standard library path:", path)
+    global active
+
+    for root, dirnames, filenames in os.walk(path):
+        dirnames_to_remove = [
+            dirname
+            for dirname in dirnames
+            if "-" in dirname
+        ]
+
+        for dirname in dirnames_to_remove:
+            dirnames.remove(dirname)
+
+        dirnames.sort()
+
+        filenames = [
+            filename
+            for filename in filenames
+            if decide(root, filename)
+        ]
+
+        for filename in sorted(filenames):
+            if not search_mode.consider(root, filename):
+                continue
+
+            full_path = os.path.join(root, filename)
+
+            my_print(full_path, ':', end = ' ')
+            sys.stdout.flush()
+
+            action(stage_dir, path, full_path)
+
+
+def compileLibraryTest(search_mode, stage_dir, decide, action):
+    my_dirname = os.path.dirname(__file__)
+
+    paths = [
+        path
+        for path in
+        sys.path
+        if not path.startswith(my_dirname)
+    ]
+
+    my_print("Using standard library paths:")
+    for path in paths:
+        my_print(path)
+
+
+    for path in paths:
+        compileLibraryPath(search_mode, path, stage_dir, decide, action)
